# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.certification_campaign_filters_api import CertificationCampaignFiltersApi


class TestCertificationCampaignFiltersApi(unittest.TestCase):
    """CertificationCampaignFiltersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CertificationCampaignFiltersApi()

    def tearDown(self) -> None:
        pass

    def test_create_campaign_filter(self) -> None:
        """Test case for create_campaign_filter

        Create Campaign Filter
        """
        pass

    def test_delete_campaign_filters(self) -> None:
        """Test case for delete_campaign_filters

        Deletes Campaign Filters
        """
        pass

    def test_get_campaign_filter_by_id(self) -> None:
        """Test case for get_campaign_filter_by_id

        Get Campaign Filter by ID
        """
        pass

    def test_list_campaign_filters(self) -> None:
        """Test case for list_campaign_filters

        List Campaign Filters
        """
        pass

    def test_update_campaign_filter(self) -> None:
        """Test case for update_campaign_filter

        Updates a Campaign Filter
        """
        pass


if __name__ == '__main__':
    unittest.main()
