# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.governance_groups_api import GovernanceGroupsApi


class TestGovernanceGroupsApi(unittest.TestCase):
    """GovernanceGroupsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GovernanceGroupsApi()

    def tearDown(self) -> None:
        pass

    def test_create_workgroup(self) -> None:
        """Test case for create_workgroup

        Create a new Governance Group.
        """
        pass

    def test_delete_workgroup(self) -> None:
        """Test case for delete_workgroup

        Delete a Governance Group
        """
        pass

    def test_delete_workgroup_members(self) -> None:
        """Test case for delete_workgroup_members

        Remove members from Governance Group
        """
        pass

    def test_delete_workgroups_in_bulk(self) -> None:
        """Test case for delete_workgroups_in_bulk

        Delete Governance Group(s)
        """
        pass

    def test_get_workgroup(self) -> None:
        """Test case for get_workgroup

        Get Governance Group by Id
        """
        pass

    def test_list_connections(self) -> None:
        """Test case for list_connections

        List connections for Governance Group
        """
        pass

    def test_list_workgroup_members(self) -> None:
        """Test case for list_workgroup_members

        List Governance Group Members
        """
        pass

    def test_list_workgroups(self) -> None:
        """Test case for list_workgroups

        List Governance Groups
        """
        pass

    def test_patch_workgroup(self) -> None:
        """Test case for patch_workgroup

        Patch a Governance Group
        """
        pass

    def test_update_workgroup_members(self) -> None:
        """Test case for update_workgroup_members

        Add members to Governance Group
        """
        pass


if __name__ == '__main__':
    unittest.main()
