# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictStr
from pydantic import Field
from sailpoint.beta.models.source1 import Source1
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class IdentityAttribute(BaseModel):
    """
    IdentityAttribute
    """ # noqa: E501
    name: StrictStr = Field(description="Identity attribute's technical name.")
    display_name: Optional[StrictStr] = Field(default=None, description="Identity attribute's business-friendly name.", alias="displayName")
    standard: Optional[StrictBool] = Field(default=False, description="Indicates whether the attribute is 'standard' or 'default'.")
    type: Optional[StrictStr] = Field(default=None, description="Identity attribute's type.")
    multi: Optional[StrictBool] = Field(default=False, description="Indicates whether the identity attribute is multi-valued.")
    searchable: Optional[StrictBool] = Field(default=False, description="Indicates whether the identity attribute is searchable.")
    system: Optional[StrictBool] = Field(default=False, description="Indicates whether the identity attribute is 'system', meaning that it doesn't have a source and isn't configurable.")
    sources: Optional[List[Source1]] = Field(default=None, description="Identity attribute's list of sources - this specifies how the rule's value is derived.")
    __properties: ClassVar[List[str]] = ["name", "displayName", "standard", "type", "multi", "searchable", "system", "sources"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of IdentityAttribute from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in sources (list)
        _items = []
        if self.sources:
            for _item in self.sources:
                if _item:
                    _items.append(_item.to_dict())
            _dict['sources'] = _items
        # set to None if type (nullable) is None
        # and model_fields_set contains the field
        if self.type is None and "type" in self.model_fields_set:
            _dict['type'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of IdentityAttribute from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "displayName": obj.get("displayName"),
            "standard": obj.get("standard") if obj.get("standard") is not None else False,
            "type": obj.get("type"),
            "multi": obj.get("multi") if obj.get("multi") is not None else False,
            "searchable": obj.get("searchable") if obj.get("searchable") is not None else False,
            "system": obj.get("system") if obj.get("system") is not None else False,
            "sources": [Source1.from_dict(_item) for _item in obj.get("sources")] if obj.get("sources") is not None else None
        })
        return _obj


