# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.iai_common_access_api import IAICommonAccessApi


class TestIAICommonAccessApi(unittest.TestCase):
    """IAICommonAccessApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IAICommonAccessApi()

    def tearDown(self) -> None:
        pass

    def test_create_common_access(self) -> None:
        """Test case for create_common_access

        Create common access items
        """
        pass

    def test_get_common_access(self) -> None:
        """Test case for get_common_access

        Get a paginated list of common access
        """
        pass

    def test_update_common_access_status_in_bulk(self) -> None:
        """Test case for update_common_access_status_in_bulk

        Bulk update common access status
        """
        pass


if __name__ == '__main__':
    unittest.main()
