# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.managed_clusters_api import ManagedClustersApi


class TestManagedClustersApi(unittest.TestCase):
    """ManagedClustersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ManagedClustersApi()

    def tearDown(self) -> None:
        pass

    def test_get_client_log_configuration(self) -> None:
        """Test case for get_client_log_configuration

        Get managed cluster's log configuration
        """
        pass

    def test_get_managed_cluster(self) -> None:
        """Test case for get_managed_cluster

        Get a specified ManagedCluster.
        """
        pass

    def test_get_managed_clusters(self) -> None:
        """Test case for get_managed_clusters

        Retrieve all Managed Clusters.
        """
        pass

    def test_put_client_log_configuration(self) -> None:
        """Test case for put_client_log_configuration

        Update managed cluster's log configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
