# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.sources_api import SourcesApi


class TestSourcesApi(unittest.TestCase):
    """SourcesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SourcesApi()

    def tearDown(self) -> None:
        pass

    def test_create_provisioning_policy(self) -> None:
        """Test case for create_provisioning_policy

        Create Provisioning Policy
        """
        pass

    def test_create_source(self) -> None:
        """Test case for create_source

        Creates a source in IdentityNow.
        """
        pass

    def test_create_source_schema(self) -> None:
        """Test case for create_source_schema

        Create Schema on Source
        """
        pass

    def test_delete(self) -> None:
        """Test case for delete

        Delete Source by ID
        """
        pass

    def test_delete_accounts_async(self) -> None:
        """Test case for delete_accounts_async

        Remove All Accounts in a Source
        """
        pass

    def test_delete_native_change_detection_config(self) -> None:
        """Test case for delete_native_change_detection_config

        Delete Native Change Detection Configuration
        """
        pass

    def test_delete_provisioning_policy(self) -> None:
        """Test case for delete_provisioning_policy

        Delete Provisioning Policy by UsageType
        """
        pass

    def test_delete_source_schema(self) -> None:
        """Test case for delete_source_schema

        Delete Source Schema by ID
        """
        pass

    def test_get_correlation_config(self) -> None:
        """Test case for get_correlation_config

        Get Source Correlation Configuration
        """
        pass

    def test_get_native_change_detection_config(self) -> None:
        """Test case for get_native_change_detection_config

        Native Change Detection Configuration
        """
        pass

    def test_get_provisioning_policy(self) -> None:
        """Test case for get_provisioning_policy

        Get Provisioning Policy by UsageType
        """
        pass

    def test_get_source(self) -> None:
        """Test case for get_source

        Get Source by ID
        """
        pass

    def test_get_source_accounts_schema(self) -> None:
        """Test case for get_source_accounts_schema

        Downloads source accounts schema template
        """
        pass

    def test_get_source_attr_sync_config(self) -> None:
        """Test case for get_source_attr_sync_config

        Attribute Sync Config
        """
        pass

    def test_get_source_config(self) -> None:
        """Test case for get_source_config

        Gets source config with language translations
        """
        pass

    def test_get_source_entitlement_request_config(self) -> None:
        """Test case for get_source_entitlement_request_config

        Get Source Entitlement Request Configuration
        """
        pass

    def test_get_source_entitlements_schema(self) -> None:
        """Test case for get_source_entitlements_schema

        Downloads source entitlements schema template
        """
        pass

    def test_get_source_schema(self) -> None:
        """Test case for get_source_schema

        Get Source Schema by ID
        """
        pass

    def test_get_source_schemas(self) -> None:
        """Test case for get_source_schemas

        List Schemas on Source
        """
        pass

    def test_import_accounts(self) -> None:
        """Test case for import_accounts

        Account Aggregation
        """
        pass

    def test_import_entitlements(self) -> None:
        """Test case for import_entitlements

        Entitlement Aggregation
        """
        pass

    def test_import_source_accounts_schema(self) -> None:
        """Test case for import_source_accounts_schema

        Uploads source accounts schema template
        """
        pass

    def test_import_source_connector_file(self) -> None:
        """Test case for import_source_connector_file

        Upload connector file to source
        """
        pass

    def test_import_source_entitlements_schema(self) -> None:
        """Test case for import_source_entitlements_schema

        Uploads source entitlements schema template
        """
        pass

    def test_import_uncorrelated_accounts(self) -> None:
        """Test case for import_uncorrelated_accounts

        Process Uncorrelated Accounts
        """
        pass

    def test_list_provisioning_policies(self) -> None:
        """Test case for list_provisioning_policies

        Lists ProvisioningPolicies
        """
        pass

    def test_list_sources(self) -> None:
        """Test case for list_sources

        Lists all sources in IdentityNow.
        """
        pass

    def test_peek_resource_objects(self) -> None:
        """Test case for peek_resource_objects

        Peek source connector's resource objects
        """
        pass

    def test_ping_cluster(self) -> None:
        """Test case for ping_cluster

        Ping cluster for source connector
        """
        pass

    def test_put_correlation_config(self) -> None:
        """Test case for put_correlation_config

        Update Source Correlation Configuration
        """
        pass

    def test_put_native_change_detection_config(self) -> None:
        """Test case for put_native_change_detection_config

        Update Native Change Detection Configuration
        """
        pass

    def test_put_provisioning_policy(self) -> None:
        """Test case for put_provisioning_policy

        Update Provisioning Policy by UsageType
        """
        pass

    def test_put_source(self) -> None:
        """Test case for put_source

        Update Source (Full)
        """
        pass

    def test_put_source_attr_sync_config(self) -> None:
        """Test case for put_source_attr_sync_config

        Update Attribute Sync Config
        """
        pass

    def test_put_source_schema(self) -> None:
        """Test case for put_source_schema

        Update Source Schema (Full)
        """
        pass

    def test_sync_attributes_for_source(self) -> None:
        """Test case for sync_attributes_for_source

        Synchronize single source attributes.
        """
        pass

    def test_test_source_configuration(self) -> None:
        """Test case for test_source_configuration

        Test configuration for source connector
        """
        pass

    def test_test_source_connection(self) -> None:
        """Test case for test_source_connection

        Check connection for source connector.
        """
        pass

    def test_update_provisioning_policies_in_bulk(self) -> None:
        """Test case for update_provisioning_policies_in_bulk

        Bulk Update Provisioning Policies
        """
        pass

    def test_update_provisioning_policy(self) -> None:
        """Test case for update_provisioning_policy

        Partial update of Provisioning Policy
        """
        pass

    def test_update_source(self) -> None:
        """Test case for update_source

        Update Source (Partial)
        """
        pass

    def test_update_source_entitlement_request_config(self) -> None:
        """Test case for update_source_entitlement_request_config

        Update Source Entitlement Request Configuration
        """
        pass

    def test_update_source_schema(self) -> None:
        """Test case for update_source_schema

        Update Source Schema (Partial)
        """
        pass


if __name__ == '__main__':
    unittest.main()
