# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.branding_api import BrandingApi


class TestBrandingApi(unittest.TestCase):
    """BrandingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BrandingApi()

    def tearDown(self) -> None:
        pass

    def test_create_branding_item(self) -> None:
        """Test case for create_branding_item

        Create a branding item
        """
        pass

    def test_delete_branding(self) -> None:
        """Test case for delete_branding

        Delete a branding item
        """
        pass

    def test_get_branding(self) -> None:
        """Test case for get_branding

        Get a branding item
        """
        pass

    def test_get_branding_list(self) -> None:
        """Test case for get_branding_list

        List of branding items
        """
        pass

    def test_set_branding_item(self) -> None:
        """Test case for set_branding_item

        Update a branding item
        """
        pass


if __name__ == '__main__':
    unittest.main()
