# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from sailpoint.beta.models.form_condition import FormCondition
from sailpoint.beta.models.form_definition_input import FormDefinitionInput
from sailpoint.beta.models.form_element import FormElement
from sailpoint.beta.models.form_owner import FormOwner
from sailpoint.beta.models.form_used_by import FormUsedBy
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class FormDefinitionResponse(BaseModel):
    """
    FormDefinitionResponse
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="Unique guid identifying the form definition.")
    name: Optional[StrictStr] = Field(default=None, description="Name of the form definition.")
    description: Optional[StrictStr] = Field(default=None, description="Form definition's description.")
    owner: Optional[FormOwner] = None
    used_by: Optional[List[FormUsedBy]] = Field(default=None, description="List of objects using the form definition. Whenever a system uses a form, the API reaches out to the form service to record that the system is currently using it.", alias="usedBy")
    form_input: Optional[List[FormDefinitionInput]] = Field(default=None, description="List of form inputs required to create a form-instance object.", alias="formInput")
    form_elements: Optional[List[FormElement]] = Field(default=None, description="List of nested form elements.", alias="formElements")
    form_conditions: Optional[List[FormCondition]] = Field(default=None, description="Conditional logic that can dynamically modify the form as the recipient is interacting with it.", alias="formConditions")
    created: Optional[datetime] = Field(default=None, description="Created is the date the form definition was created")
    modified: Optional[datetime] = Field(default=None, description="Modified is the last date the form definition was modified")
    __properties: ClassVar[List[str]] = ["id", "name", "description", "owner", "usedBy", "formInput", "formElements", "formConditions", "created", "modified"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FormDefinitionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in used_by (list)
        _items = []
        if self.used_by:
            for _item in self.used_by:
                if _item:
                    _items.append(_item.to_dict())
            _dict['usedBy'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in form_input (list)
        _items = []
        if self.form_input:
            for _item in self.form_input:
                if _item:
                    _items.append(_item.to_dict())
            _dict['formInput'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in form_elements (list)
        _items = []
        if self.form_elements:
            for _item in self.form_elements:
                if _item:
                    _items.append(_item.to_dict())
            _dict['formElements'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in form_conditions (list)
        _items = []
        if self.form_conditions:
            for _item in self.form_conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['formConditions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of FormDefinitionResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "owner": FormOwner.from_dict(obj.get("owner")) if obj.get("owner") is not None else None,
            "usedBy": [FormUsedBy.from_dict(_item) for _item in obj.get("usedBy")] if obj.get("usedBy") is not None else None,
            "formInput": [FormDefinitionInput.from_dict(_item) for _item in obj.get("formInput")] if obj.get("formInput") is not None else None,
            "formElements": [FormElement.from_dict(_item) for _item in obj.get("formElements")] if obj.get("formElements") is not None else None,
            "formConditions": [FormCondition.from_dict(_item) for _item in obj.get("formConditions")] if obj.get("formConditions") is not None else None,
            "created": obj.get("created"),
            "modified": obj.get("modified")
        })
        return _obj


