# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.auth_users_api import AuthUsersApi


class TestAuthUsersApi(unittest.TestCase):
    """AuthUsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthUsersApi()

    def tearDown(self) -> None:
        pass

    def test_get_auth_user(self) -> None:
        """Test case for get_auth_user

        Auth User Details
        """
        pass

    def test_patch_auth_user(self) -> None:
        """Test case for patch_auth_user

        Auth User Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
