# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.managed_clients_api import ManagedClientsApi


class TestManagedClientsApi(unittest.TestCase):
    """ManagedClientsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ManagedClientsApi()

    def tearDown(self) -> None:
        pass

    def test_get_managed_client_status(self) -> None:
        """Test case for get_managed_client_status

        Specified Managed Client Status.
        """
        pass

    def test_update_managed_client_status(self) -> None:
        """Test case for update_managed_client_status

        Handle status request from client
        """
        pass


if __name__ == '__main__':
    unittest.main()
