# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.password_configuration_api import PasswordConfigurationApi


class TestPasswordConfigurationApi(unittest.TestCase):
    """PasswordConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PasswordConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_create_password_org_config(self) -> None:
        """Test case for create_password_org_config

        Create Password Org Config
        """
        pass

    def test_get_password_org_config(self) -> None:
        """Test case for get_password_org_config

        Get Password Org Config
        """
        pass

    def test_put_password_org_config(self) -> None:
        """Test case for put_password_org_config

        Update Password Org Config
        """
        pass


if __name__ == '__main__':
    unittest.main()
